@@ -395,9 +395,6 @@ function Staff:checkIfNeedRest()
       -- If occupied by patient, staff will go to the staffroom after the patient left.
       self.staffroom_needed = true
     else
-      if room then
-        room.staff_leaving = true
-      end
       self:goToStaffRoom()
     end
   end
@@ -511,10 +508,8 @@ function Staff:isIdle()
         return true
       else
         -- It might still be the case that the patient is leaving
-        for _, action in ipairs(room:getPatient().action_queue) do
-          if action.is_leaving then
-            return true
-          end
+        if room:getPatient():isLeaving() then
+          return true
         end
       end
     end
@@ -533,7 +528,7 @@ function Staff:isIdle()
   return false
 end
 
--- Makes the staff member request a raise of 10%, or a wage exactly inbetween their current and a fair one, whichever is more.
+-- Makes the staff member request a raise of 10%, or a wage exactly in the middle of their current and a fair one, whichever is more.
 function Staff:requestRaise()
   -- Is this the first time a member of staff is requesting a raise?
   -- Only show the help if the player is playing the campaign though
