@@ -244,9 +244,9 @@ end
 
 --! Get the primary tile which the object is attached to for rendering
 --[[! For objects which attach to a single tile for rendering, this method will
-return the X and Y Lua world co-ordinates of that tile. For objects which split
+return the X and Y Lua world coordinates of that tile. For objects which split
 their rendering over multiple tiles, one of them is arbitrarily designated as
-the primary tile, and its co-ordinates are returned.
+the primary tile, and its coordinates are returned.
 ]]
 function Object:getRenderAttachTile()
   local x, y = self.tile_x, self.tile_y
