@@ -70,7 +70,7 @@ local action_seek_room_find_room = permanent"action_seek_room_find_room"( functi
         return room
       else
         tried_rooms = tried_rooms + 1
-        -- Remove the index of this room from the list of indeces available in available_diagnosis_rooms
+        -- Remove the index of this room from the list of indices available in available_diagnosis_rooms
         table.remove(available_rooms, room_at_index)
         -- If the room can be built, set the flag for it.
         local diag = humanoid.world.available_rooms[room_type]
@@ -107,7 +107,6 @@ local action_seek_room_goto_room = permanent"action_seek_room_goto_room"( functi
   humanoid.next_room_to_visit = room
   humanoid:updateDynamicInfo(_S.dynamic_info.patient.actions.on_my_way_to
     :format(room.room_info.name))
-  room.door.queue:expect(humanoid)
   room.door:updateDynamicInfo()
   if not room:testStaffCriteria(room:getRequiredStaffCriteria()) then
     humanoid.world.dispatcher:callForStaff(room)
@@ -358,7 +357,7 @@ local function action_seek_room_start(action, humanoid)
         -- don't need this as we unregistered all previous callbacks if we went to research
         local room_req = humanoid.hospital:checkDiseaseRequirements(humanoid.disease.id)
         -- get required staff
-        if not room_req then
+        if not humanoid.diagnosed or not room_req then
           action_seek_room_goto_room(rm, humanoid, action.diagnosis_room)
           TheApp.ui.bottom_panel:removeMessage(humanoid)
           humanoid:unregisterRoomBuildCallback(build_callback)
